@@ -20,37 +20,23 @@
 #ifndef GENERALOPTIONSPAGE_H
 #define GENERALOPTIONSPAGE_H
 
-#include "SettingsPage.h"
+#include <QScopedPointer>
+#include <QWidget>
 
-class QButtonGroup;
-class QCheckBox;
-class QRadioButton;
+class Ui_GeneralOptions;
 
-class GeneralOptionsPage : public SettingsPage
+class GeneralOptionsPage : public QWidget
 {
     Q_OBJECT
 
     public:
 
     explicit GeneralOptionsPage(QWidget *parent = nullptr);
-
-    public Q_SLOTS:
-
-    void saveChanges() override;
-    void resetChanges() override;
-
-    private Q_SLOTS:
-
-    void markDirty();
+    ~GeneralOptionsPage() override;
 
     private:
 
-    QButtonGroup* mPrintKeyActionGroup;
-    QRadioButton* mRememberAlways;
-    QRadioButton* mRememberUntilClosed;
-    QCheckBox *mUseLightBackground;
-    QCheckBox *mShowMagnifier;
-    QCheckBox *mReleaseToCapture;
+    QScopedPointer<Ui_GeneralOptions> m_ui;
 };
 
 #endif // GENERALOPTIONSPAGE_H
